@@ -7,7 +7,7 @@ use Moose;
 use MooseX::Accessors::ReadWritePrivate;
 
 
-use version; our $VERSION = qv('v1.17.0');
+use version; our $VERSION = qv('v1.18.0');
 
 
 with 'MooseX::Getopt::Defanged';
@@ -18,6 +18,7 @@ foreach my $type (
         Str
         Int
         Num
+        RegexpRef
         ArrayRef
         ArrayRef[Str]
         ArrayRef[Int]
@@ -64,4 +65,4 @@ MooseX::Getopt::Defanged::ConsumerOfAllTypes - Consumer of L<MooseX::Getopt::Def
 
 # setup vim: set filetype=perl tabstop=4 softtabstop=4 expandtab :
 # setup vim: set shiftwidth=4 shiftround textwidth=78 autoindent :
-# setup vim: set foldmethod=indent foldlevel=0 encoding=utf8 :
+# setup vim: set foldmethod=indent foldlevel=0 fileencoding=utf8 :
