@@ -6,7 +6,7 @@ use utf8;
 use Moose;
 
 
-use version; our $VERSION = qv('v1.17.0');
+use version; our $VERSION = qv('v1.18.0');
 
 
 with 'MooseX::Getopt::Defanged';
@@ -17,6 +17,7 @@ foreach my $type (
         Str
         Int
         Num
+        RegexpRef
         ArrayRef
         ArrayRef[Str]
         ArrayRef[Int]
@@ -63,4 +64,4 @@ MooseX::Getopt::Defanged::Meta::Attribute::Trait::_Getopt::ConsumerOfAllTypesWit
 
 # setup vim: set filetype=perl tabstop=4 softtabstop=4 expandtab :
 # setup vim: set shiftwidth=4 shiftround textwidth=78 autoindent :
-# setup vim: set foldmethod=indent foldlevel=0 encoding=utf8 :
+# setup vim: set foldmethod=indent foldlevel=0 fileencoding=utf8 :
